@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
-from zope.i18nmessageid import MessageFactory
 from plone.api import env
+from zope.i18nmessageid import MessageFactory
 
 
-_ = MessageFactory('collective.collectionfilter')
+_ = MessageFactory("collective.collectionfilter")
 
 PLONE_VERSION = env.plone_version()
